.. _pecan_middleware_debug:

:mod:`pecan.middleware.debug` -- Pecan Debugging Middleware 
===========================================================

.. automodule:: pecan.middleware.debug
  :members:
  :show-inheritance:

